@@ -40,9 +40,13 @@
 #'   # using a matrix of class Matrix. 
 #'   
 #'   data("A_Matrix")
+#'   A_Matrix <- A_Matrix[1:100,1:50]
+#'   #small for the example
 #'   PMA_Matrix <- getPM(A_Matrix)
 #'   mismutex <- getMutex(A=A_Matrix,PM=PMA_Matrix)
 #'   
+#'   
+#'   \dontrun{
 #'   #Finally, the last example, shows a real 
 #'   #example of how to perform this function when using 
 #'   #data from TCGA, Colon Adenocarcinoma in this case. 
@@ -52,6 +56,7 @@
 #'   
 #'   PM_COAD <- getMutex(TCGA_COAD, PM_COAD)
 #'   }
+#'   }
 #'
 #' @import Matrix
 #' @import parallel
@@ -438,8 +443,8 @@ getMutex <- function(A = NULL, PM = getPM(A), lower.tail = TRUE,
           miniPM <- as.matrix(PM[match(levels(genes_factor),PM@rowExps),])
           llx <- combn(nrow(miniPM),2)
           llx <- cbind(llx,rbind(c(1:nrow(miniPM)),c(1:nrow(miniPM))))
-          II_2 <- cbind(which(Idx[,II[,1]] == 1,arr.ind = T)[,1],
-                        which(Idx[,II[,2]] == 1,arr.ind = T)[,1])
+          II_2 <- cbind(which(Idx[,II[,1],drop=FALSE] == 1,arr.ind = T)[,1],
+                        which(Idx[,II[,2],drop=FALSE] == 1,arr.ind = T)[,1])
           pos <- factor(II_2 %*% rnorm(2))
           
           # cat("length_pos=",length(levels(pos)),"\nII_2 = ",nrow(II_2),"\n")
